==> marray_1.24.0.zip: marray/doc/marrayClassesShort.R <==
###################################################
### chunk number 1: 
###################################################
library(marray)
data(swirl)


###################################################
### chunk number 2: 
###################################################
slotNames("marrayLayout")
slotNames(swirl)


###################################################
### chunk number 3: 
###################################################
zebra.RG<-as.data.frame(cbind(c("swirl","WT","swirl","WT"), c("WT","swirl","WT","swirl"))) 
dimnames(zebra.RG)[[2]]<-c("Cy3","Cy5")
zebra.samples<-new("marrayInfo",
		    maLabels=paste("Swirl array ",1:4,sep=""), 
		    maInfo=zebra.RG,
		    maNotes="Description of targets for Swirl experiment")
zebra.samples


###################################################
### chunk number 4: 
###################################################
L<-slot(swirl, "maLayout")
L@maNgr


###################################################
### chunk number 5:  eval=FALSE
###################################################
## showMethods(classes="marrayLayout")
## showMethods("summary",classes="marrayLayout") 


###################################################
### chunk number 6: 
###################################################
showMethods("print")


###################################################
### chunk number 7: 
###################################################
summary(swirl)


###################################################
### chunk number 8: 
###################################################
swirl[1:100,2:3]


###################################################
### chunk number 9: 
###################################################
swirl.layout<-maLayout(swirl)
maNspots(swirl)
maNspots(swirl.layout)
maNgr(swirl)
maNgc(swirl.layout)
maPrintTip(swirl[1:10,3])


###################################################
### chunk number 10: 
###################################################
maNotes(swirl.layout)
maNotes(swirl.layout)<- "New value"
maNotes(swirl.layout)


###################################################
### chunk number 11: 
###################################################
L<-new("marrayLayout")
L
maNgr(L)<-4


###################################################
### chunk number 12: 
###################################################
swirl.norm<-as(swirl, "marrayNorm")    


###################################################
### chunk number 13: 
###################################################
maPlate(swirl)<-maCompPlate(swirl,n=384)

==> marray_1.28.0.zip: marray/doc/marrayClassesShort.R <==
###################################################
### chunk number 1: 
###################################################
#line 54 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
library(marray)
data(swirl)


###################################################
### chunk number 2: 
###################################################
#line 99 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
slotNames("marrayLayout")
slotNames(swirl)


###################################################
### chunk number 3: 
###################################################
#line 112 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
zebra.RG<-as.data.frame(cbind(c("swirl","WT","swirl","WT"), c("WT","swirl","WT","swirl"))) 
dimnames(zebra.RG)[[2]]<-c("Cy3","Cy5")
zebra.samples<-new("marrayInfo",
		    maLabels=paste("Swirl array ",1:4,sep=""), 
		    maInfo=zebra.RG,
		    maNotes="Description of targets for Swirl experiment")
zebra.samples


###################################################
### chunk number 4: 
###################################################
#line 135 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
L<-slot(swirl, "maLayout")
L@maNgr


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 147 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
## showMethods(classes="marrayLayout")
## showMethods("summary",classes="marrayLayout") 


###################################################
### chunk number 6: 
###################################################
#line 160 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
showMethods("print")


###################################################
### chunk number 7: 
###################################################
#line 167 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
summary(swirl)


###################################################
### chunk number 8: 
###################################################
#line 182 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
swirl[1:100,2:3]


###################################################
### chunk number 9: 
###################################################
#line 211 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
swirl.layout<-maLayout(swirl)
maNspots(swirl)
maNspots(swirl.layout)
maNgr(swirl)
maNgc(swirl.layout)
maPrintTip(swirl[1:10,3])


###################################################
### chunk number 10: 
###################################################
#line 229 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
maNotes(swirl.layout)
maNotes(swirl.layout)<- "New value"
maNotes(swirl.layout)


###################################################
### chunk number 11: 
###################################################
#line 237 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
L<-new("marrayLayout")
L
maNgr(L)<-4


###################################################
### chunk number 12: 
###################################################
#line 254 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
swirl.norm<-as(swirl, "marrayNorm")    


###################################################
### chunk number 13: 
###################################################
#line 270 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayClassesShort.Rnw"
maPlate(swirl)<-maCompPlate(swirl,n=384)
